county

# XMLRésuméLibrary: User Guide

country | Element Reference | date

## Name

county — A county name

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `county` element specifies the name of a county (not to be confused with `country`). In the United States, a county is “an administrative subdivision of a state”. In the UK, it is a “territorial division exercising administrative, judicial, and political functions.” (Source: The American Heritage Dictionary of the English Language, 1979 Ed. Houghton Mifflin, Boston.)

### Parents

`county` may be contained in these elements: `address`, `location`

### Attributes

`id`

  A string used to uniquely identify a county. The county may then be referred to by this identifier.

## See Also

`state`, `province`, `prefecture`.

## Examples

    <address>
      <city>North Willow</city>
      <county>Washington</county>
      <state>New Canada</state>
    </address>

    <address>
      <street>1 O'Leary Place</street>
      <city>Coby</city>
      <county>Co. Cork</county>
      <country>Ireland</country>
    </address>

country | Element Reference | date